@@ -15,7 +15,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
  
@@ -40,6 +40,8 @@ private:
 	QString name;
 public:	
 	NewIODlg(StrGlobal *glob, DlgType t);
+
+	int init();
 	
 	StrIOBase *getNewIO();
 public slots:
